@@ -17,21 +17,19 @@
 import datetime
 from copy import copy
 from enum import Enum
+from typing import Optional, Dict, Any, Union
 
-from pm4py.objects.log import obj as log_instance
-from pm4py.objects.petri_net import semantics
-from pm4py.objects.petri_net.utils import final_marking as final_marking_discovery
-from pm4py.objects.petri_net.obj import PetriNet
-from pm4py.objects.stochastic_petri import utils as stochastic_utils
 from pm4py.algo.simulation.montecarlo.utils import replay
+from pm4py.objects import petri_net
+from pm4py.objects.log import obj as log_instance
+from pm4py.objects.log.obj import EventLog
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+from pm4py.objects.petri_net.utils import final_marking as final_marking_discovery
+from pm4py.objects.stochastic_petri import utils as stochastic_utils
 from pm4py.util import constants
 from pm4py.util import exec_utils
 from pm4py.util import xes_constants
 
-from pm4py.objects.petri_net.obj import PetriNet, Marking
-from typing import Optional, Dict, Any, Union, Tuple
-from pm4py.objects.log.obj import EventLog, EventStream
-
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
@@ -42,12 +40,14 @@ class Parameters(Enum):
     MAX_TRACE_LENGTH = "maxTraceLength"
     LOG = "log"
     STOCHASTIC_MAP = "stochastic_map"
+    PETRI_SEMANTICS = "petri_semantics"
 
 
 def apply_playout(net, initial_marking, no_traces=100, max_trace_length=100,
                   case_id_key=xes_constants.DEFAULT_TRACEID_KEY,
                   activity_key=xes_constants.DEFAULT_NAME_KEY, timestamp_key=xes_constants.DEFAULT_TIMESTAMP_KEY,
-                  final_marking=None, smap=None, log=None, return_visited_elements=False):
+                  final_marking=None, smap=None, log=None, return_visited_elements=False,
+                  semantics=petri_net.semantics.ClassicSemantics()):
     """
     Do the playout of a Petrinet generating a log
 
@@ -73,6 +73,8 @@ def apply_playout(net, initial_marking, no_traces=100, max_trace_length=100,
         Stochastic map
     log
         Log
+    semantics
+        Semantics of the Petri net to be used (default: petri_net.semantics.ClassicSemantics())
     """
     if final_marking is None:
         # infer the final marking from the net
@@ -137,7 +139,8 @@ def apply_playout(net, initial_marking, no_traces=100, max_trace_length=100,
     return log
 
 
-def apply(net: PetriNet, initial_marking: Marking, final_marking: Marking = None, parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
+def apply(net: PetriNet, initial_marking: Marking, final_marking: Marking = None,
+          parameters: Optional[Dict[Union[str, Parameters], Any]] = None) -> EventLog:
     """
     Do the playout of a Petrinet generating a log
 
@@ -153,6 +156,7 @@ def apply(net: PetriNet, initial_marking: Marking, final_marking: Marking = None
         Parameters of the algorithm:
             Parameters.NO_TRACES -> Number of traces of the log to generate
             Parameters.MAX_TRACE_LENGTH -> Maximum trace length
+            Parameters.PETRI_SEMANTICS -> Petri net semantics to be used (default: petri_nets.semantics.ClassicSemantics())
     """
     if parameters is None:
         parameters = {}
@@ -165,7 +169,10 @@ def apply(net: PetriNet, initial_marking: Marking, final_marking: Marking = None
     smap = exec_utils.get_param_value(Parameters.STOCHASTIC_MAP, parameters, None)
     log = exec_utils.get_param_value(Parameters.LOG, parameters, None)
     return_visited_elements = exec_utils.get_param_value(Parameters.RETURN_VISITED_ELEMENTS, parameters, False)
+    semantics = exec_utils.get_param_value(Parameters.PETRI_SEMANTICS, parameters, petri_net.semantics.ClassicSemantics())
 
     return apply_playout(net, initial_marking, max_trace_length=max_trace_length, no_traces=no_traces,
                          case_id_key=case_id_key, activity_key=activity_key, timestamp_key=timestamp_key,
-                         final_marking=final_marking, smap=smap, log=log, return_visited_elements=return_visited_elements)
+                         final_marking=final_marking, smap=smap, log=log,
+                         return_visited_elements=return_visited_elements,
+                         semantics=semantics)
